﻿
using System;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Input;

namespace Silo {

	[Flags]
	public enum InputButtons {
		None,
		Left = 1 << 0,
		Right = 1 << 1,
		Reset = 1 << 2,
		Exit = 1 << 3,
		ToggleScreen = 1 << 4,
	}

	public class InputState {
		InputButtons previous;
		InputButtons current;
		InputButtons down;
		InputButtons up;

		public void Update() {
			GamePadState state = GamePad.GetState(PlayerIndex.One);
			KeyboardState keyboardState = Keyboard.GetState();
			current = InputButtons.None;
			if (state.DPad.Left == ButtonState.Pressed || keyboardState.IsKeyDown(Keys.Left))
				current |= InputButtons.Left;
			if (state.DPad.Right == ButtonState.Pressed || keyboardState.IsKeyDown(Keys.Right))
				current |= InputButtons.Right;
			if (state.Buttons.Y == ButtonState.Pressed || keyboardState.IsKeyDown(Keys.Space))
				current |= InputButtons.Reset;
			if (state.Buttons.Back == ButtonState.Pressed || keyboardState.IsKeyDown(Keys.Escape))
				current |= InputButtons.Exit;
			if (state.Buttons.Start == ButtonState.Pressed || keyboardState.IsKeyDown(Keys.Enter))
				current |= InputButtons.ToggleScreen;
			down = current & ~previous;
			up = ~current & previous;
			previous = current;
		}
		public InputButtons Current { get { return current; } }
		public InputButtons Previous { get { return previous; } }
		public InputButtons Down { get { return down; } }
		public InputButtons Up { get { return up; } }
	}

}
