﻿
using System;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

namespace Silo {

	[Flags]
	public enum Alignment {
		Top = 0,
		Bottom = 1,
	}

	public class TextComponent : DrawableGameComponent {
		SpriteBatch sprites;
		SpriteFont font;
		string text = string.Empty;
		Vector2 position;
		Color color = Color.White;
		Alignment alignment;

		public TextComponent(Game game)
			: base(game) {
		}
		public Vector2 Position { get { return position; } set { position = value; } }
		public Color Color { get { return color; } set { color = value; } }
		public SpriteFont Font { get { return font; } set { font = value; } }
		public string Text { get { return text; } set { text = value; } }
		public Alignment Alignment { get { return alignment; } set { alignment = value; } }
		protected override void LoadGraphicsContent(bool loadAllContent) {
			if (loadAllContent) {
				sprites = new SpriteBatch(GraphicsDevice);
			}
		}
		protected override void UnloadGraphicsContent(bool unloadAllContent) {
			if (unloadAllContent) {
				sprites.Dispose();
			}
			base.UnloadGraphicsContent(unloadAllContent);
		}
		public override void Draw(GameTime gameTime) {
			if (!string.IsNullOrEmpty(text)) {
				sprites.Begin(SpriteBlendMode.AlphaBlend, SpriteSortMode.Immediate, SaveStateMode.SaveState);
				if (alignment == Alignment.Top) {
					sprites.DrawString(font, text, position, color);
				} else {
					Vector2 size = font.MeasureString(text);
					Viewport viewport = GraphicsDevice.Viewport;
					sprites.DrawString(font, text, position + new Vector2(0, viewport.Height - size.Y), color);
				}
				sprites.End();
			}
			base.Draw(gameTime);
		}
	}

}
